#!/bin/bash
#
# Run script against every item in input file

if [[ -z $1 ]] ; then
	echo "parse a list of parameters and execute script with those parameters"
	echo "parse-list.sh <param file> <script> [<noisy> <additional> <additional> <additional>]"
  echo "<param file> name of file containing parameters"
  echo "<script> script to run (e.g. rename-e-smith-pkh.sh)"
  echo "optional params can appear in any order"
  echo "   <review> show line being executed but do NOTHING!"
  echo "   <noisy> show line being executed"
  echo "   <additional> additional params to be passed (up to 3)"
  exit 0
fi

# parse the command line parameters
PROCESSORG=
EXTRAPARAMS=
# using a file as input
if [[ ! -f $1 ]] ; then
    echo "Can NOT find $1 - Aborting"
    exit 1
fi

if [[ $(which $2 | grep "no $2") ]] ; then 
    echo "Can NOT find $2 - Aborting"
    exit 1
fi

DEBUG=
REVIEW=
NOISY=
for param in $3 $4 $5 $6; do
  if [ $param ] ; then
    case $param in
      review )
        REVIEW=true ;;
      noisy )
        NOISY=true ;;
      ;;
      debug )
        DEBUG=true ;;
      * )
        EXTRAPARAMS=$EXTRAPARAMS" "$param ;;
    esac
  else
	  break
  fi
done

# Build array of parameters to cycle through
PARAMLIST=()
# load array of parameters from input file
while read -r line ; do PARAMLIST+=($line) ; done < $1

# Cycle through array of parameters and execute script
for param in ${PARAMLIST[@]}
do
  if [[ $NOISY || $REVIEW ]] ; then echo "$2 $param $EXTRAPARAMS" ; fi
  if [[ -z $REVIEW ]] ; then
    if [[ $param ]] ; then 
      RESPONSE=$($2 $param $EXTRAPARAMS) ; rc=$?
      if [ $rc -ne 0 ] ; then echo "($rc)\n$RESPONSE" ; fi
      if [ $DEBUG ] ; then echo "RESPONSE=$RESPONSE" ; fi
    fi
  fi
done

exit 0

